==> pdapi-1.20.4+1.0.1-sources.jar: ml/pluto7073/pdapi/addition/action/ChorusTeleportAction.java <==
package ml.pluto7073.pdapi.addition.action;

import com.google.gson.JsonObject;
import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_2540;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import net.minecraft.class_4019;
import net.minecraft.class_5712;

public class ChorusTeleportAction implements OnDrinkAction {

    private final int radius;

    public ChorusTeleportAction(int radius) {
        this.radius = radius;
    }

    @Override
    public void onDrink(class_1799 stack, class_1937 level, class_1309 user) {
        double d = user.method_23317();
        double e = user.method_23318();
        double f = user.method_23321();

        for(int i = 0; i < 16; ++i) {
            double g = user.method_23317() + (user.method_6051().method_43058() - 0.5) * radius * 2;
            double h = class_3532.method_15350(user.method_23318() + (double)(user.method_6051().method_43048(radius * 2) - radius), level.method_31607(), level.method_31607() + ((class_3218)level).method_32819() - 1);
            double j = user.method_23321() + (user.method_6051().method_43058() - 0.5) * radius * 2;
            if (user.method_5765()) {
                user.method_5848();
            }

            class_243 vec3d = user.method_19538();
            if (user.method_6082(g, h, j, true)) {
                level.method_32888(class_5712.field_39446, vec3d, class_5712.class_7397.method_43285(user));
                class_3414 soundEvent = user instanceof class_4019 ? class_3417.field_24630 : class_3417.field_14890;
                level.method_43128(null, d, e, f, soundEvent, class_3419.field_15248, 1.0F, 1.0F);
                user.method_5783(soundEvent, 1.0F, 1.0F);
                user.method_38785();
                break;
            }
        }
    }

    @Override
    public OnDrinkSerializer<?> serializer() {
        return OnDrinkSerializers.CHORUS_TELEPORT;
    }

    public static class Serializer implements OnDrinkSerializer<ChorusTeleportAction> {

        public static final Codec<ChorusTeleportAction> CODEC = RecordCodecBuilder.create(instance ->
                instance.group(Codec.INT.fieldOf("maxRadius").forGetter(action -> action.radius))
                        .apply(instance, ChorusTeleportAction::new));

        @Override
        public Codec<ChorusTeleportAction> codec() {
            return CODEC;
        }

        @Override
        public ChorusTeleportAction fromNetwork(class_2540 buf) {
            return new ChorusTeleportAction(buf.readInt());
        }

        @Override
        public void toNetwork(class_2540 buf, ChorusTeleportAction action) {
            buf.method_53002(action.radius);
        }
    }

}

==> pdapi-1.20.6+2.0.1-sources.jar: ml/pluto7073/pdapi/addition/action/ChorusTeleportAction.java <==
package ml.pluto7073.pdapi.addition.action;

import com.google.gson.JsonObject;
import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_2540;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import net.minecraft.class_4019;
import net.minecraft.class_5712;
import net.minecraft.class_9129;
import net.minecraft.class_9139;

public class ChorusTeleportAction implements OnDrinkAction {

    private final int radius;

    public ChorusTeleportAction(int radius) {
        this.radius = radius;
    }

    @Override
    public void onDrink(class_1799 stack, class_1937 level, class_1309 user) {
        double d = user.method_23317();
        double e = user.method_23318();
        double f = user.method_23321();

        for(int i = 0; i < 16; ++i) {
            double g = user.method_23317() + (user.method_6051().method_43058() - 0.5) * radius * 2;
            double h = class_3532.method_15350(user.method_23318() + (double)(user.method_6051().method_43048(radius * 2) - radius), level.method_31607(), level.method_31607() + ((class_3218)level).method_32819() - 1);
            double j = user.method_23321() + (user.method_6051().method_43058() - 0.5) * radius * 2;
            if (user.method_5765()) {
                user.method_5848();
            }

            class_243 vec3d = user.method_19538();
            if (user.method_6082(g, h, j, true)) {
                level.method_32888(class_5712.field_39446, vec3d, class_5712.class_7397.method_43285(user));
                class_3414 soundEvent = user instanceof class_4019 ? class_3417.field_24630 : class_3417.field_14890;
                level.method_43128(null, d, e, f, soundEvent, class_3419.field_15248, 1.0F, 1.0F);
                user.method_5783(soundEvent, 1.0F, 1.0F);
                user.method_38785();
                break;
            }
        }
    }

    @Override
    public OnDrinkSerializer<?> serializer() {
        return OnDrinkSerializers.CHORUS_TELEPORT;
    }

    public static class Serializer implements OnDrinkSerializer<ChorusTeleportAction> {

        public static final MapCodec<ChorusTeleportAction> CODEC = RecordCodecBuilder.mapCodec(instance ->
                instance.group(Codec.INT.fieldOf("maxRadius").forGetter(action -> action.radius))
                        .apply(instance, ChorusTeleportAction::new));
        public static final class_9139<class_9129, ChorusTeleportAction> STREAM_CODEC =
                class_9139.method_56437(Serializer::toNetwork, Serializer::fromNetwork);

        @Override
        public MapCodec<ChorusTeleportAction> codec() {
            return CODEC;
        }

        @Override
        public class_9139<class_9129, ChorusTeleportAction> streamCodec() {
            return STREAM_CODEC;
        }

        public static ChorusTeleportAction fromNetwork(class_2540 buf) {
            return new ChorusTeleportAction(buf.readInt());
        }

        public static void toNetwork(class_2540 buf, ChorusTeleportAction action) {
            buf.method_53002(action.radius);
        }
    }

}
